@@ -96,9 +96,6 @@ update_os_data (GisPrivacyPage *page)
     {
       name = get_item (buffer, "NAME");
       privacy_policy = get_item (buffer, "PRIVACY_POLICY_URL");
-      /* Fedora had PRIVACY_POLICY=... in os-release for a while, unfortunately */
-      if (!privacy_policy)
-        privacy_policy = get_item (buffer, "PRIVACY_POLICY");
       g_free (buffer);
     }
 
@@ -106,7 +103,7 @@ update_os_data (GisPrivacyPage *page)
     name = g_strdup ("GNOME");
 
   /* Translators: the parameter here is the name of a distribution,
-   * like "Fedora" or "Ubuntu". It falls back to "GNOME 3" if we can't
+   * like "Fedora" or "Ubuntu". It falls back to "GNOME" if we can't
    * detect any distribution.
    */
   text = g_strdup_printf (_("Sending reports of technical problems helps us to improve %s. Reports are sent anonymously and are scrubbed of personal data."), name);
